Module registry

Module registry 

Task registry for tracking and managing task lifecycle.

Structs

RetentionPolicy
How long, and how many, completed tasks the registry keeps observable.
TaskRegistry
Public task registry facade used by executor lifecycle tracking and tests.